@@ -61,13 +61,11 @@ sub sanitizer {
 			return $string;
 		} else {return 0;}
 	} elsif ($type eq "x2gosid") {
-		$string =~ s/[^a-zA-Z0-9\_\-\$\.\@]//g;
-		if ($string =~ /^([a-zA-Z0-9\_\-\$\.\@]*)$/) {
+		$string =~ s/[^a-zA-Z0-9\.\_\-\@]//g;
+		if ($string =~ /^([a-zA-Z0-9\.\_\-\@]*)$/) {
 			$string = $1;
-			if ($string =~ /^([a-zA-Z\_][a-zA-Z0-9\_\-\.\@]{0,47}[\$]?)\-([\d]{2,4})\-([\d]{9,12})\_[a-zA-Z0-9\_\-\.]*\_dp[\d]{1,2}$/) {
-				if ((length($1) > 0) and (length($1) < 48)){
-					return $string;
-				} else {return 0;}
+			if ($string =~ /^([a-zA-Z0-9\.\_][a-zA-Z0-9\.\_\-\@]*)\-([\d]{2,4})\-([\d]{9,12})\_[a-zA-Z0-9\.\_\-]*\_dp[\d]{1,2}$/) {
+				return $string;
 			} else {return 0;}
 		} else {return 0;}
 	} elsif ($type eq "SOMETHINGELSE") {
@@ -509,6 +507,46 @@ elsif($cmd eq  "listsessions_all")
 	}
 	fetchrow_printall_array($sth);
 }
+
+elsif($cmd eq  "listshadowsessions")
+{
+	my $server=shift or die "argument \"server\" missed";
+	my @strings;
+	my $sth=$dbh->prepare("select agent_pid, session_id, display, server, status,
+	                       strftime('%Y-%m-%dT%H:%M:%S',init_time),
+	                       cookie,client,gr_port,sound_port,
+	                       strftime('%Y-%m-%dT%H:%M:%S',last_time),
+	                       uname,
+	                       strftime('%s','now','localtime') - strftime('%s',init_time),fs_port from sessions
+	                       where status !='F' and server=? and uname=?
+	                       and (session_id like '%XSHAD%') order by status desc");
+	$sth->execute($server, $realuser);
+	if ($sth->err())
+	{
+		syslog('error', "listshadowsessions (SQLite3 session db backend) failed with exitcode: $sth->err()");
+		die();
+	}
+	fetchrow_printall_array($sth);
+}
+
+elsif($cmd eq  "listshadowsessions_all")
+{
+	my @strings;
+	my $sth=$dbh->prepare("select agent_pid, session_id, display, server, status,
+	                       strftime('%Y-%m-%dT%H:%M:%S',init_time),
+	                       cookie,client,gr_port,sound_port,
+	                       strftime('%Y-%m-%dT%H:%M:%S',last_time),
+	                       uname,
+	                       strftime('%s','now','localtime') - strftime('%s',init_time),fs_port from sessions
+	                       where status !='F' and uname=? and (session_id like '%XSHAD%') order by status desc");
+	$sth->execute($realuser);
+	if ($sth->err())
+	{
+		syslog('error', "listshadowsessions_all (SQLite3 session db backend) failed with exitcode: $sth->err()");
+		die();
+	}
+	fetchrow_printall_array($sth);
+}
 else
 {
 	print "unknown command $cmd\n";
